# timexwiz
timexwiz - это небольшая библиотека для проведения интеллектуальных замеров процессорного времени, позволяющая проводить замеры времени
выполнения однотипных (с одинаковым интерфейсом) функций на одинаковом наборе данных, затрачивая на это заданное в секундах время.

## Установка

Вы можете установить timexwiz с помощью pip:

```bash
pip install timexwiz
```

## Лицензия

Этот проект лицензирован под лицензией MIT.
Подробнее смотрите файл [LICENSE](LICENSE).